# PEP 690: Lazy Imports Again

**URL:** <https://discuss.python.org/t/pep-690-lazy-imports-again/19661>\
**Category:** PEPs\
**Created:** [October 3, 2022, 4:09pm UTC](https://discuss.python.org/t/pep-690-lazy-imports-again/19661 "2022-10-03T16:09:53Z")\
**Posts on this page:** 1\
**Showing post:** 12

<div class="post-metadata">

**Author:** ![Kronuz](https://sea2.discourse-cdn.com/flex002/user_avatar/discuss.python.org/kronuz/32/7101_2.png) [@Kronuz](https://discuss.python.org/u/Kronuz)\
**Post date:** [October 17, 2022, 7:30pm UTC](https://discuss.python.org/t/pep-690-lazy-imports-again/19661/12 "2022-10-17T19:30:33Z")

</div>

I did a few optimizations and re-ran the experiments in the same machine. The geometric mean is now:

- `1.00x slower` — CPython vs. Lazy Imports disabled.
- `1.01x slower` — CPython vs. Lazy Imports enabled.
- `1.01x slower` — Lazy Imports disabled vs. Lazy Imports enabled.

You can check the detailed results in the same link: [cpython/README.md at lazy\_imports-pyperformance · Kronuz/cpython · GitHub](https://github.com/Kronuz/cpython/blob/lazy_imports-pyperformance/lazy_imports-pyperformance/README.md)

cc: @guido, @markshannon

---

_[View the full topic](https://discuss.python.org/t/pep-690-lazy-imports-again/19661)._
